==> react-form-builder-1.21.0.tgz: package/lib/Standard/Fields/Picker/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import Switch from '../../../Switch';
import Select from '../../../Select';
import Checkbox from '../../../Checkbox';
import InlineButton from '../../../InlineButton';
import { FIELDS, DISPLAYS } from '../../index';

var PickerField = function PickerField(_ref) {
  var field = _ref.field,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts;

  if (field.display === DISPLAYS[FIELDS.PICKER].SWITCH) {
    return React.createElement(Switch, {
      switchField: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].AUTOCOMPLETE || field.display === DISPLAYS[FIELDS.PICKER].DROPDOWN) {
    return React.createElement(Select, {
      select: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].RADIO) {
    return React.createElement("p", null, "radio button TODO");
  } else if (field.display === DISPLAYS[FIELDS.PICKER].CHECKBOX) {
    return React.createElement(Checkbox, {
      checkbox: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].BUTTON_INLINE) {
    return React.createElement(InlineButton, {
      inlineButton: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  } else {
    // TODO: should be removed (backwards compatibility)
    return React.createElement(Select, {
      select: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  }
};

export default PickerField;

==> react-form-builder-1.27.0.tgz: package/lib/Standard/Fields/Picker/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import Switch from '../../../Switch';
import Select from '../../../Select';
import Checkbox from '../../../Checkbox';
import InlineButton from '../../../InlineButton';
import Radio from '../../../Radio';
import { FIELDS, DISPLAYS } from '../../index';

var PickerField = function PickerField(_ref) {
  var field = _ref.field,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts;

  if (field.display === DISPLAYS[FIELDS.PICKER].SWITCH) {
    return React.createElement(Switch, {
      switchField: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].AUTOCOMPLETE || field.display === DISPLAYS[FIELDS.PICKER].DROPDOWN) {
    return React.createElement(Select, {
      select: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].RADIO) {
    return React.createElement(Radio, {
      radio: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].CHECKBOX) {
    return React.createElement(Checkbox, {
      checkbox: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  } else if (field.display === DISPLAYS[FIELDS.PICKER].BUTTON_INLINE) {
    return React.createElement(InlineButton, {
      inlineButton: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  } else {
    // TODO: should be removed (backwards compatibility)
    return React.createElement(Select, {
      select: field,
      onChange: onChange,
      onBlur: onBlur,
      tabIndex: tabIndex,
      errors: errors,
      alerts: alerts
    });
  }
};

export default PickerField;
